==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTreeSelectionOptionsEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescription } from "./WebTreeSelectionOptionsEventDetailDescription";
/**
 * @hidden
 */
export let WebTreeSelectionOptionsEventDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeSelectionOptionsEventDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeSelectionOptionsEventDetailDescriptionMetadata.a == null) {
                WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeSelectionOptionsEventDetailDescriptionMetadata.c(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
            }
            if (a.j(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventDetail");
            a.item("NewSelection", "Collection:WebTreeItem:WebTreeItemCollection:WebTreeItem");
        }
        static d(a) {
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.b(a);
            a.aa("WebTreeSelectionOptionsEventDetail", () => new WebTreeSelectionOptionsEventDetailDescription());
            a.z("WebTreeSelectionOptionsEventDetail", WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
    }
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeSelectionOptionsEventDetailDescriptionMetadata, 'WebTreeSelectionOptionsEventDetailDescriptionMetadata');
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebTreeSelectionOptionsEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescription } from "./WebTreeSelectionOptionsEventDetailDescription";
/**
 * @hidden
 */
export let WebTreeSelectionOptionsEventDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTreeSelectionOptionsEventDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebTreeSelectionOptionsEventDetailDescriptionMetadata.a == null) {
                WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTreeSelectionOptionsEventDetailDescriptionMetadata.c(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
            }
            if (a.k(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("NewSelection", "Collection:WebTreeItem:WebTreeItemCollection:WebTreeItem");
        }
        static d(a) {
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.b(a);
            a.ac("WebTreeSelectionOptionsEventDetail", () => new WebTreeSelectionOptionsEventDetailDescription());
            a.ab("WebTreeSelectionOptionsEventDetail", WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
    }
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTreeSelectionOptionsEventDetailDescriptionMetadata, 'WebTreeSelectionOptionsEventDetailDescriptionMetadata');
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventDetailDescriptionMetadata;
})();
